@@ -14,6 +14,14 @@ async def get_player_by_name(name: str) -> MojangPlayer:
     return MojangPlayer(await response.json())
 
 
+async def get_player_by_uuid(uuid: str) -> MojangPlayer:
+    async with aiohttp.ClientSession() as session:
+        response = await session.get(f"{MOJANG_SESSION_SERVER}/session/minecraft/profile/{uuid.replace('-', '')}")
+        if response.status != 200:
+            raise NoPlayerFoundError
+    return MojangPlayer(await response.json())
+
+
 async def get_player_name_history(uuid: str) -> NameHistory:
     async with aiohttp.ClientSession() as session:
         response = await session.get(f"{MOJANG_API}/user/profiles/{uuid}/names")
