@@ -129,7 +129,14 @@ def get_ratio(positive_stat, negative_stat):
         ratio = positive_stat / negative_stat
         return round(ratio, 2)
     except ZeroDivisionError:
-        return 0
+        return float("inf") if positive_stat > 0 else 0
+
+
+def get_ratio_next(ratio):
+    if ratio == float("inf"):
+        return ratio
+    else:
+        return math.trunc(ratio) + 1
 
 
 def get_increase(positive_stat, negative_stat, *, amount: int = 0):
